#!/usr/bin/env python

"""
synopsis:
    An API wrapper for `ddgr` which can be called from Python.
    For more info on `ddgr`, see -- https://pypi.org/project/ddgr/.
exports:
    `retrieve_search_results` -- a function.  See below.
"""

import sys
import os
import ddgr


def retrieve_search_results(keywords, opts_overrides={}):
    """
    Retrieve search engine results.

    Parameters
    ----------
    keywords : str
        The string for which to search the Web.

    Returns
    -------
    A list of dict
        The search results

    """

    opts = ddgr.parse_args()

    opts.json = True
    opts.ducky = False
    opts.keywords = keywords

    # Set logging level
    if opts.debug:
        ddgr.LOGGER.setLevel(ddgr.logging.DEBUG)
        ddgr.LOGDBG(
            'ddgr version %s Python version %s',
            ddgr._VERSION_,
            ddgr.python_version())

    # Handle query completer
    if opts.complete is not None:
        ddgr.completer_run(opts.complete)

    ddgr.check_stdout_encoding()

    # Add cmdline args to readline history
    if opts.keywords:
        try:
            ddgr.readline.add_history(' '.join(opts.keywords))
        except Exception:
            pass

    # Set colors
    colorize = ddgr.get_colorize(opts.colorize)
    colors = ddgr.Colors(
        *[ddgr.COLORMAP[c] for c in opts.colorstr],
        reset=ddgr.COLORMAP['x']) if colorize else None
    ddgr.Result.colors = colors
    ddgr.Result.urlexpand = opts.expand
    ddgr.DdgCmd.colors = colors

    repl = ddgr.DdgCmd(opts, '' if opts.noua else ddgr.USER_AGENT)

    repl.fetch()
    json_results = [result.jsonizable_object() for
                    result in repl.results]
    return json_results


def main():
    args = sys.argv[1:]
    if len(args) != 1:
        sys.exit(__doc__)
    keywords = args[0]
    results = retrieve_search_results(keywords)
    import pprint
    pprint.pprint(results)


if __name__ == '__main__':
    # import ipdb; ipdb.set_trace()
    main()
