#!/usr/bin/env python3

"""
synopsis:
    Do a Web search.
    Write JSON string to stdout.
usage:
    python json_from_search.py <some search terms>
example:
    python json_from_search.py "python docs"
"""


import sys
import json
import ddgr_api as api

def json_from_search(search_words):
    """Search and write out (JSON) string.
    """
    json_items = api.retrieve_search_results(search_words)
    for idx, item in enumerate(json_items):
        if not item['abstract']:
            item['abstract'] = '<empty>'
        elif len(item['abstract']) > 254:
            item['abstract'] = item['abstract'][0:254]
        json_items[idx] = item
    json_data = {
        'searchstr': search_words,
        'items': json_items,
    }
    json.dump(json_data, sys.stdout)


def main():
    args = sys.argv[1:]
    if len(args) != 1:
        sys.exit('usage: xxx')
    search_words = args[0]
    json_from_search(search_words)


if __name__ == '__main__':
    main()
