defmodule Sedb.CLI do
  @moduledoc """
  ## synopsis:

    Add or list search result records in the project database.
    Read input from stdin.
    The input is JSON.

  ## usage

      $ sedb <command>

  where <command> = "add" or "list".

  ## examples

      $ cat input_file.json > ./sedb add
      $ ./sedb list
  """
  def main(args) do
    case args do
      ["add"] ->                     
        add_records()
      ["list"] ->
        list_records()
      _ ->
        IO.puts(@moduledoc)
    end
  end

  def add_records do
    jsonstr = IO.read(:stdio, :eof)
    {:ok, jasonstruct} = Jason.decode(jsonstr)
    searchstr = jasonstruct["searchstr"]
    items = jasonstruct["items"]
    items |> Enum.each(fn item ->
      item1 = Map.put(item, "searchstr", searchstr)
      IO.puts(~s(searchstr: #{item1["searchstr"]}))
      IO.puts(~s(title: #{item1["title"]}))
      IO.puts(~s(url: #{item1["url"]}))
      IO.puts(~s(abstract: #{item1["abstract"]}))
      IO.puts("----")
      {:ok, _} = Sedb.Searchresults.create_searchresult(item1)
    end)
  end

  def list_records do
    searchresults = Sedb.Searchresults.list_searchresults
    searchresults
    |> Enum.with_index()
    |> Enum.each(fn {searchresult, idx} ->
      IO.puts("#{idx + 1}. search result -- id: #{searchresult.id}:")
      IO.puts("    searchstr: #{searchresult.searchstr}")
      IO.puts("    title: #{searchresult.title}")
      IO.puts("    abstract: #{searchresult.abstract}")
      IO.puts("    url: #{searchresult.url}")
    end)
  end

end
